@@ -22,8 +22,8 @@ logger = logging.getLogger(__name__)
 
 try:
     import greynirseq.nicenlp.utils.constituency.chart_parser as chart_parser  # pylint: disable=no-name-in-module
-except ImportError:
-    logger.warn("Unable to import parsing dependencies, missing cython compilation. Parsing will not work")
+except Exception as e:
+    logger.warn(f"Failed to import chart_parser: {e}. Parsing will not work.")
 
 
 class ChartParserHead(nn.Module):
