@@ -292,7 +292,7 @@ class GPT2WordDropout(GPT2Noising):
             modified_lengths.append(len(new_s))
         # re-construct input
         modified_lengths = torch.tensor(modified_lengths).long()
-        modified_x = torch.tensor(modified_lengths.max(), modified_lengths.size(0)).long().fill_(self.dictionary.pad())
+        modified_x = torch.full((int(modified_lengths.max().item()), modified_lengths.size(0)), self.dictionary.pad())
         for i in range(modified_lengths.size(0)):
             modified_x[: modified_lengths[i], i].copy_(torch.tensor(sentences[i]).long())
 
@@ -517,6 +517,8 @@ class TranslationWithBacktranslationTask(TranslationTask):
         super(TranslationWithBacktranslationTask, TranslationWithBacktranslationTask).add_args(parser)
         """Add task-specific arguments to the parser."""
         # fmt: off
+        parser.add_argument('--skip-backtranslation-data', default=False, action='store_true', help='Should we skip reading the backtranslation data? \
+This is useful to set if you have no backtranslation data but would like the BPE noise on the main training data.')  # noqa
         parser.add_argument('--max-word-shuffle-distance', default=3.0, type=float, metavar='N',
                             help='maximum word shuffle distance for denoising autoencoding data generation')
         parser.add_argument('--word-dropout-prob', default=0.1, type=float, metavar='N',
@@ -596,7 +598,7 @@ class TranslationWithBacktranslationTask(TranslationTask):
             )
 
         # load backtranslation
-        if is_train_subset:
+        if is_train_subset and not self.args.skip_backtranslation_data:
             """
             noised vs unnoised valdation set? they might converge at different times
             """
